<?php
namespace Ep\Woo\Plugin\Ajax;

use Ep\Wp\Plugin\PluginInterface;
use WC_Product_Variation;

class AddToCart implements PluginInterface
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        if (defined('DOING_AJAX')) {
            add_action('wp_ajax_ep_add_to_cart', [$this, 'action']);
            add_action('wp_ajax_nopriv_ep_add_to_cart', [$this, 'action']);
        }
    }

    /**
     * @throws \Exception
     */
    public function action()
    {
        ob_start();

        $cart = WC()->cart;
        $cart->get_cart();

        if (isset($_POST['products']) && is_array($_POST['products'])) {
            $added = [];

            foreach ($_POST['products'] as $productId => $quantity) {
                $quantity = intval($quantity);
                $productId = apply_filters('woocommerce_add_to_cart_product_id', absint($productId));
                $isValid = apply_filters('woocommerce_add_to_cart_validation', true, $productId, $quantity);
                $productStatus = get_post_status($productId);

                $product = wc_get_product($productId);

                $isOk = $product instanceof WC_Product_Variation
                    ? $cart->add_to_cart($product->get_parent_id(), $quantity, $productId)
                    : $cart->add_to_cart($productId, $quantity);

                if ($isValid && 'publish' === $productStatus && false !== $isOk) {
                    $added[$productId] = $quantity;
                    do_action('woocommerce_ajax_added_to_cart', $productId);
                }
            }

            if (count($added) > 0) {
                wc_add_to_cart_message($added, true);
            }
        }

        ob_start();
        woocommerce_mini_cart();
        $miniCart = ob_get_clean();

        ob_start();
        wc_print_notices();
        $notices = ob_get_clean();

        $data = array(
            'fragments' => apply_filters('woocommerce_add_to_cart_fragments', [
                'div.widget_shopping_cart_content' => '<div class="widget_shopping_cart_content">' . $miniCart . '</div>',
                '#' . $_POST['form_id'] . ' .add-to-cart__messages' => '<div class="add-to-cart__messages">' . $notices . '</div>',
            ]),
            'cart_hash' => apply_filters('woocommerce_add_to_cart_hash',
                $cart->get_cart_for_session() ? md5(json_encode($cart->get_cart_for_session())) : '',
                $cart->get_cart_for_session()
            ),
            'messages' => $notices,
        );

        wp_send_json($data);
    }
}