<?php
namespace Ep\Woo\View;

class BrandFilter extends AbstractView
{
    protected $templateOverrides = [
        'brand-filter.php',
    ];

    public function render(): string
    {
        /** @var \WP_Term[] $brands */
        $brands = get_terms([
            'taxonomy' => 'product_brand',
            'category' => get_queried_object_id(),
        ]);

        if (0 === count($brands)) {
            return '';
        }

        $currentBrands = [];

        if (isset($_GET['brands'])) {
            $currentBrands = explode(',', $_GET['brands']);
        }

        $active = [];
        $inactive = [];

        foreach ($brands as $brand) {
            $ids = $currentBrands;
            $isActive = in_array($brand->term_id, $ids);

            if ($isActive) {
                unset($ids[array_search($brand->term_id, $ids)]);
            } else {
                $ids[] = $brand->term_id;
            }

            $baseUrl = preg_replace('#/page/\d+/?#', '', $_SERVER['REQUEST_URI']);
            $baseUrl = preg_replace('#\?.+$#', '', $baseUrl);

            $item = [
                'active' => $isActive,
                'url' => $baseUrl . '?brands=' . implode(',', array_filter($ids)),
                'name' => $brand->name,
                'image' => $brand->image,
            ];

            if ($isActive) {
                $active[] = $item;
            } else {
                $inactive[] = $item;
            }
        }

        $viewBrands = array_merge($active, $inactive);

        return $this->getRenderer()->render('@woo/brand-filter.html.twig', [
            'brands' => $viewBrands,
        ]);
    }
}