<?php
namespace Ep\Woo\View;

use Ep\Woo\Product\Grouped;

/**
 * Onaj Draženov slavni prikaz proizvoda :).
 *
 * @package Ep\Woo\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class ContentProduct extends AbstractView
{
    /** @var array */
    protected $templatePartOverrides = [
        'content-product.php',
    ];

    /** @var array */
    protected $config;

    /**
     * ContentProduct constructor.
     *
     * @param array $config
     */
    public function __construct(array $config)
    {
        $this->config = $config;
    }

    /**
     * Renderira proizvod.
     *
     * @return string
     */
    public function render(): string
    {
        /** @var \WC_Product $product */
        global $product;

        if (!is_object($product) || !$product->is_visible()) {
            return '';
        }

        if ($product instanceof Grouped) {
            $template = '@woo/content-product-grouped.html.twig';
        } else {
            $template = '@woo/content-product.html.twig';
        }

        $templateVars = [
            'product' => $product,

            'thumbnail' => woocommerce_get_product_thumbnail(),
            'description'        => $product->get_short_description(),
            'is_featured'        => $product->is_featured(),
            'show_out_of_stock'  => $this->config['show_out_of_stock_on_image'] ?? true,
            'out_of_stock'       => get_post_meta($product->get_id(), '_stock_status', true) === 'outofstock',
            'out_of_stock_label' => __('Out of stock', 'woocommerce'),
            'product_sku'        => $product->get_sku(),
            'product_url'        => get_permalink($product->get_id()),
            'short_description'  => wp_trim_words($product->get_short_description(), 15),
        ];

        return $this->renderer->render($template, $templateVars);
    }
}